==> haskell-oeis-0.3.10.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.1
visibility:           public
id:                   oeis-0.3.10.1-k9AyTzyaVRAsjnxPj6hY9
key:                  oeis-0.3.10.1-k9AyTzyaVRAsjnxPj6hY9
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  89487a2602cdbdae996a4c0b089df0ee
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.1-k9AyTzyaVRAsjnxPj6hY9
depends:
    base-4.17.2.1 http-client-0.7.18-7J2pWtgV41wCh8tO4e8XTa
    http-client-tls-0.3.6.4-JK4I6xiNtggFn7ElWv8VCk
    http-types-0.12.4-6IzIilaA47l58TRShghvhm
    network-3.1.4.0-24l6wfZeDaoIo68scGYLPE
    network-uri-2.6.4.2-EjZpKZ4F93eKYvVi9AsGV0
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-oeis-0.3.10.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.1
visibility:           public
id:                   oeis-0.3.10.1-FdhToilBnxiAHThTa18nD6
key:                  oeis-0.3.10.1-FdhToilBnxiAHThTa18nD6
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  11b26c9a9280fd2b9f8eebd974234e6a
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.1-FdhToilBnxiAHThTa18nD6
depends:
    base-4.17.2.1 http-client-0.7.18-FHhdytn5xYS9XZS4tP326d
    http-client-tls-0.3.6.4-6ViG6xajb6OInvSbADfE1E
    http-types-0.12.4-BDoys3Aesb9DkjEWopUdY6
    network-3.1.4.0-IeirKeGjruDCEk80u2jHD1
    network-uri-2.6.4.2-BSIANA0b7f4FqAKAmElYJ
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
